@@ -1,4 +1,4 @@
-# $Id: __init__.py 9283 2022-11-28 23:55:57Z milde $
+# $Id: __init__.py 9544 2024-02-17 10:37:45Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -479,15 +479,36 @@ def relative_path(source, target):
     """
     Build and return a path to `target`, relative to `source` (both files).
 
-    Differences to `os.relpath()`:
+    The return value is a `str` suitable to be included in `source`
+    as a reference to `target`.
+
+    :Parameters:
+        `source` : path-like object or None
+            Path of a file in the start directory for the relative path
+            (the file does not need to exist).
+            The value ``None`` is replaced with "<cwd>/dummy_file".
+        `target` : path-like object
+            End point of the returned relative path.
+
+    Differences to `os.path.relpath()`:
 
     * Inverse argument order.
-    * `source` expects path to a FILE (while os.relpath expects a dir)!
-      (Add a "dummy" file name if `source` points to a directory.)
+    * `source` is assumed to be a FILE in the start directory (add a "dummy"
+      file name to obtain the path relative from a directory)
+      while `os.path.relpath()` expects a DIRECTORY as `start` argument.
     * Always use Posix path separator ("/") for the output.
-    * Use `os.sep` for parsing the input (ignored by `os.relpath()`).
+    * Use `os.sep` for parsing the input
+      (changing the value of `os.sep` is ignored by `os.relpath()`).
     * If there is no common prefix, return the absolute path to `target`.
 
+    Differences to `pathlib.PurePath.relative_to(other)`:
+
+    * pathlib offers an object oriented interface.
+    * `source` expects path to a FILE while `other` expects a DIRECTORY.
+    * `target` defaults to the cwd, no default value for `other`.
+    * `relative_path()` always returns a path (relative or absolute),
+      while `PurePath.relative_to()` raises a ValueError
+      if `target` is not a subpath of `other` (no ".." inserted).
     """
     source_parts = os.path.abspath(source or type(target)('dummy_file')
                                    ).split(os.sep)
